@@ -102,7 +102,8 @@ typedef struct proc_t {
 	cmin_flt,	/* cumulative min_flt of process and child processes */
 	cmaj_flt,	/* cumulative maj_flt of process and child processes */
 	nswap,		/* ? */
-	cnswap,		/* cumulative nswap ? */
+	cnswap;		/* cumulative nswap ? */
+    unsigned KLONG
 	start_code,	/* address of beginning of code segment */
 	end_code,	/* address of end of code segment */
 	start_stack,	/* address of the bottom of stack for the process */
@@ -132,6 +133,7 @@ typedef struct proc_t {
 	session,	/* session id */
 	tty,		/* full device number of controlling terminal */
 	tpgid,		/* terminal process group id */
+	tgid,		/* thread group ID */
 	exit_signal,	/* might not be SIGCHLD */
 	processor;      /* current (or most recent?) CPU */
 #ifdef FLASK_LINUX
@@ -211,7 +213,6 @@ extern void freeproc(proc_t* p);
 #define PROC_FILLWCHAN  0x0080 /* look up WCHAN name */
 #define PROC_FILLARG    0x0100 /* alloc and fill in `cmdline' */
 
-#define PROC_FILLBUG    0x0fff /* No idea what we need */
 #define PROC_FILLANY    0x0000 /* either stat or status will do */
 
 /* Obsolete, consider only processes with one of the passed: */
