@@ -40,6 +40,7 @@
 #define SEL_TTY  11
 #define SEL_SESS 12
 #define SEL_COMM 13
+#define SEL_PPID 14
 
 /* Since an enum could be smashed by a #define, it would be bad. */
 #define U98  0 /* Unix98 standard */    /* This must be 0 */
@@ -143,10 +144,11 @@
 
 typedef union sel_union {
   pid_t pid;
+  pid_t ppid;
   uid_t uid;
   gid_t gid;
   dev_t tty;
-  char  cmd[8];  /* this is _not_ \0 terminated */
+  char  cmd[16];  /* this is _not_ \0 terminated */
 } sel_union;
 
 typedef struct selection_node {
